From: Pascal Schmidt <der.eremit@email.de>
To: Manfred Spraul <manfred@colorfullife.com>
Cc: linux-kernel@vger.kernel.org
Subject: Re: [CFT] faster athlon/duron memory copy implementation
Date: Thu, 24 Oct 2002 21:33:02 +0200 [thread overview]
Message-ID: <E184nj4-0000Qo-00@neptune.sol.net> (raw)
In-Reply-To: <3DB82ABF.8030706@colorfullife.com>
On Thu, 24 Oct 2002 19:20:13 +0200, you wrote in linux.kernel:
> Attached is a test app that compares several memory copy implementations.
> Could you run it and report the results to me, together with cpu,
> chipset and memory type?
CPU: AMD Duron Spitfire 1 GHz
Chipset: ALi 1647 (Magik 1)
Memory: 2x 256 MB DDR-SDRAM at 200 MHz
> Please run 2 or 3 times.
CFLAGS="-march=athlon" make athlon
[pharao90@neptune (ttyp2) ~]$ ./athlon
Athlon test program $Id: fast.c,v 1.6 2000/09/23 09:05:45 arjan Exp $
copy_page() tests
copy_page function 'warm up run' took 20604 cycles per page
copy_page function '2.4 non MMX' took 26798 cycles per page
copy_page function '2.4 MMX fallback' took 27143 cycles per page
copy_page function '2.4 MMX version' took 20835 cycles per page
copy_page function 'faster_copy' took 12324 cycles per page
copy_page function 'even_faster' took 12615 cycles per page
copy_page function 'no_prefetch' took 10842 cycles per page
[pharao90@neptune (ttyp2) ~]$ ./athlon
Athlon test program $Id: fast.c,v 1.6 2000/09/23 09:05:45 arjan Exp $
copy_page() tests
copy_page function 'warm up run' took 25284 cycles per page
copy_page function '2.4 non MMX' took 31419 cycles per page
copy_page function '2.4 MMX fallback' took 30724 cycles per page
copy_page function '2.4 MMX version' took 25246 cycles per page
copy_page function 'faster_copy' took 15462 cycles per page
copy_page function 'even_faster' took 16504 cycles per page
copy_page function 'no_prefetch' took 10179 cycles per page
[pharao90@neptune (ttyp2) ~]$ ./athlon
Athlon test program $Id: fast.c,v 1.6 2000/09/23 09:05:45 arjan Exp $
copy_page() tests
copy_page function 'warm up run' took 22943 cycles per page
copy_page function '2.4 non MMX' took 30414 cycles per page
copy_page function '2.4 MMX fallback' took 30703 cycles per page
copy_page function '2.4 MMX version' took 23345 cycles per page
copy_page function 'faster_copy' took 14878 cycles per page
copy_page function 'even_faster' took 14902 cycles per page
copy_page function 'no_prefetch' took 10872 cycles per page
Note that even_faster is always slower than faster_copy. ;)
--
Ciao,
Pascal
next prev parent reply other threads:[~2002-10-24 19:26 UTC|newest]
Thread overview: 51+ messages / expand[flat|nested] mbox.gz Atom feed top
2002-10-24 17:15 Manfred Spraul
2002-10-24 17:37 ` Robert Love
2002-10-24 18:05 ` Zach Brown
2002-10-24 17:41 ` Andreas Steinmetz
2002-10-24 17:48 ` Matthias Welk
2002-10-24 19:01 ` erich
2002-10-24 19:11 ` Arjan van de Ven
2002-10-24 19:38 ` Manfred Spraul
2002-10-25 0:59 ` Panagiotis Papadakos
2002-10-24 17:53 ` Roger Luethi
2002-10-24 18:10 ` Daniel Egger
2002-10-24 19:15 ` Florin Iucha
2002-10-24 19:28 ` Manfred Spraul
2002-10-24 19:38 ` Dave Jones
2002-10-24 19:43 ` Ken Witherow
2002-10-25 13:08 ` Daniel Egger
2002-10-24 18:17 ` Eric Lammerts
2002-10-24 18:26 ` David Rees
2002-10-24 18:35 ` Josh McKinney
2002-10-24 18:36 ` Dave Jones
2002-10-24 18:43 ` Simon Fowler
2002-10-24 18:50 ` Simon Fowler
2002-10-24 18:56 ` Dave Jones
2002-10-24 18:48 ` Ernst Herzberg
2002-10-24 20:09 ` Ed Sweetman
2002-10-24 20:13 ` Robert Love
2002-10-24 20:31 ` Ed Sweetman
2002-10-24 20:49 ` Dave Jones
2002-10-24 20:26 ` Dave Jones
2002-10-25 9:19 ` Måns Rullgård
2002-10-24 19:11 ` Marcus Libäck
2002-10-24 19:19 ` Brian Gerst
2002-10-24 19:31 ` Matthias Schniedermeyer
2002-10-24 19:33 ` Pascal Schmidt [this message]
2002-10-24 19:39 ` Olaf Dietsche
2002-10-24 20:27 ` Mike Civil
2002-10-24 20:44 ` Willy TARREAU
2002-10-24 21:46 ` Josh Fryman
2002-10-24 22:18 ` Tim Schmielau
2002-10-24 23:09 ` Hirokazu Takahashi
2002-10-24 23:37 ` Ryan Cumming
2002-10-25 0:10 ` Matthias Andree
2002-10-25 8:35 ` venom
2002-10-25 13:31 ` Denis Vlasenko
2002-10-26 12:11 ` Jurjen Oskam
2002-10-24 18:27 Shawn Starr
2002-10-24 20:51 Dieter Nützel
2002-10-24 21:01 ` Dieter Nützel
2002-10-24 21:16 ` Willy TARREAU
2002-10-24 22:01 Harm Verhagen
2002-10-25 16:29 Jorge Bernal "Koke"
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=E184nj4-0000Qo-00@neptune.sol.net \
--to=der.eremit@email.de \
--cc=linux-kernel@vger.kernel.org \
--cc=manfred@colorfullife.com \
--cc=pharao90@tzi.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®